Skip to contents

Reads the hub's record of designation statuses used to generate the ensemble for that reference date (via generate_hub_ensemble()), not the current designation statuses.

Usage

get_model_designation_as_of(
  base_hub_path,
  reference_date,
  model_ids = NULL,
  targets = NULL
)

Arguments

base_hub_path

character, path to the base hub directory.

reference_date

character or Date, the reference date to resolve designation as of.

model_ids

character vector of model IDs to include, or NULL (default) to include every model in that reference date's record

targets

character vector of target names to include, or NULL (default) to include all targets supported by the hub.

Value

A tibble with columns model_id, target, and designated (logical), with one row per (model, target) combination. model_ids with no submission for the reference date have an NA designation status.