Skip to contents

Returns a cloud storage path for a supported forecast hub that can be passed to hubData::connect_hub() and related hubverse connect_* functions in place of a local hub directory path. This avoids having to check out the hub's GitHub repository to read its data.

Usage

hub_cloud_path(disease, anonymous = TRUE, ...)

Arguments

disease

Disease identifier for the hub. One of "covid", "rsv", or "flu".

anonymous

Logical. Use anonymous (unauthenticated) access to the hub's S3 bucket? Passed through to hubData::s3_bucket(). The hubverse buckets are public and hubData interactions are read-only, so this defaults to TRUE.

...

Additional keyword arguments passed through to hubData::s3_bucket().

Value

A <SubTreeFileSystem> object pointing at the hub's S3 bucket.

Examples

hub_cloud_path("rsv")
#> SubTreeFileSystem: s3://rsv-forecast-hub/

hub_cloud_path("covid")$base_path
#> [1] "covid19-forecast-hub/"