Check hospital reporting data latency and completeness.
Source:R/write_webtext.R
check_hospital_reporting_rate.RdThis function retrieves hospital reporting data from data.cdc.gov and checks for data latency and reporting completeness issues. It returns a flag string describing any reporting issues.
Arguments
- reference_date
Date, the reference date for the forecast.
- disease
Character, disease name ("covid" or "rsv").
- excluded_hosp_locations
Character vector of US state/territory abbreviations to exclude from expected reporting locations. Pre-resolved for the hospital admissions target by the caller. Default: NULL (no exclusions).