Get and format NHSN data for a given disease.
Source:R/update_hub_target_data.R
get_hubverse_format_nhsn_data.RdThis function pulls the NHSN hospital admissions data, formats and returns it in the hubverse format. Missing observations before each location's first reported week within the requested date range are dropped.
Usage
get_hubverse_format_nhsn_data(
disease,
as_of = lubridate::today(),
start_date = NULL,
end_date = NULL,
date_col_name = "target_end_date"
)Arguments
- disease
Disease name ("covid" or "rsv").
- as_of
As-of date of the data pull. Default is the system date as determined by
lubridate::today().- start_date
First week-ending date to include for the NHSN dataset. Default value is NULL (no filtering).
- end_date
Last week-ending date to include for the NHSN dataset. Default value is NULL (no filtering).
- date_col_name
Character. Name for the date column in the output. Default is "target_end_date".