Get and format NHSN data for a given disease.
Source:R/update_hub_target_data.R
get_hubverse_format_nhsn_data.RdThis function pulls the NHSN hospital admissions data, formats and returns it in the hubverse format.
Usage
get_hubverse_format_nhsn_data(
disease,
as_of = lubridate::today(),
included_locations = hubhelpr::included_locations,
start_date = NULL,
end_date = NULL
)Arguments
- disease
Disease name ("covid" or "rsv").
- as_of
As-of date of the data pull. Default is the system date as determined by
lubridate::today().- included_locations
Vector of location codes to include in the output. Default value
hubhelpr::included_locations.- start_date
First week-ending date to include for the NHSN dataset. Default value is NULL (no filtering).
- end_date
Last week-ending date to include for the NHSN dataset. Default value is NULL (no filtering).